# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`polkit`](#polkit): Set up PolicyKit
* [`polkit::install`](#polkit--install): Manage the polkit package
* [`polkit::service`](#polkit--service): Ensure that the polkit service is running
* [`polkit::user`](#polkit--user): Manage the `polkit` user
* [`polkit::user::hidepid_notify`](#polkit--user--hidepid_notify): A notification for hidepid user creation

### Defined types

* [`polkit::authorization::basic_policy`](#polkit--authorization--basic_policy): Add a rule file containing javascript Polkit configuration to the system
* [`polkit::authorization::rule`](#polkit--authorization--rule): Add a rule file containing javascript Polkit configuration to the system
* [`polkit::local_authority`](#polkit--local_authority): Add PolicyKit Local Authority policies to a system  Only the default ``authority`` directories are currently supported

### Functions

* [`polkit::validate_identity`](#polkit--validate_identity): Validate that all entries are valid PolicyKit identities per pkla-check-authorization(8).  Abort catalog compilation if any entry fails this 

### Data types

* [`Polkit::Authority`](#Polkit--Authority): polkit authority types
* [`Polkit::PackageEnsure`](#Polkit--PackageEnsure): Package ensure type
* [`Polkit::Result`](#Polkit--Result): Polkit result types

## Classes

### <a name="polkit"></a>`polkit`

Allows you to set up and manipulate PolicyKit objects

* **See also**
  * http://www.freedesktop.org/software/polkit/docs/latest/
    * PolicyKit Documentation

#### Parameters

The following parameters are available in the `polkit` class:

* [`manage_polkit_user`](#-polkit--manage_polkit_user)
* [`package_ensure`](#-polkit--package_ensure)
* [`warn_on_unsupported_os`](#-polkit--warn_on_unsupported_os)

##### <a name="-polkit--manage_polkit_user"></a>`manage_polkit_user`

Data type: `Boolean`

Enables managment of the `$polkit_user`

* Enabled by default since newer versions of polkit require the
  `$polkit_user` to be in the group assigned to /proc to function properly

@see `polkit::user`

Default value: `true`

##### <a name="-polkit--package_ensure"></a>`package_ensure`

Data type: `Polkit::PackageEnsure`

The ensure status of packages

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-polkit--warn_on_unsupported_os"></a>`warn_on_unsupported_os`

Data type: `Boolean`

Warn if the module is trying to be used on an unsupported OS

* The module will not fail on an unsupported OS but also will not perform
  any action

Default value: `true`

### <a name="polkit--install"></a>`polkit::install`

Manage the polkit package

#### Parameters

The following parameters are available in the `polkit::install` class:

* [`package_name`](#-polkit--install--package_name)
* [`package_ensure`](#-polkit--install--package_ensure)

##### <a name="-polkit--install--package_name"></a>`package_name`

Data type: `String[1]`

The name of the package to manage

Default value: `'polkit'`

##### <a name="-polkit--install--package_ensure"></a>`package_ensure`

Data type: `Variant[String[1],Boolean]`

`ensure` state from the service resource

Default value: `$polkit::package_ensure`

### <a name="polkit--service"></a>`polkit::service`

Ensure that the polkit service is running

#### Parameters

The following parameters are available in the `polkit::service` class:

* [`ensure`](#-polkit--service--ensure)
* [`enable`](#-polkit--service--enable)
* [`service_name`](#-polkit--service--service_name)

##### <a name="-polkit--service--ensure"></a>`ensure`

Data type: `Variant[String[1],Boolean]`

`ensure` state from the service resource

Default value: `'running'`

##### <a name="-polkit--service--enable"></a>`enable`

Data type: `Boolean`

`enable` state from the service resource

Default value: `true`

##### <a name="-polkit--service--service_name"></a>`service_name`

Data type: `String[1]`

The `name` of the service to manage

Default value: `'polkit'`

### <a name="polkit--user"></a>`polkit::user`

Manage the `polkit` user

#### Parameters

The following parameters are available in the `polkit::user` class:

* [`user`](#-polkit--user--user)
* [`user_options`](#-polkit--user--user_options)
* [`report_proc_issues`](#-polkit--user--report_proc_issues)

##### <a name="-polkit--user--user"></a>`user`

Data type: `String[1]`

The user that `polkit` runs as

Default value: `'polkitd'`

##### <a name="-polkit--user--user_options"></a>`user_options`

Data type: `Hash`

Allows setting of any of the usual puppet `User` resource options. Will
have the GID assigned to `/proc` added to the `groups` to preserve proper
system functionality.

Default value: `{}`

##### <a name="-polkit--user--report_proc_issues"></a>`report_proc_issues`

Data type: `Boolean`

Actively notify the user about issues with the `hidepid` setting on the
`/proc` filesystem

Default value: `true`

### <a name="polkit--user--hidepid_notify"></a>`polkit::user::hidepid_notify`

This was moved into a separate class for resource notification chaining correctness

#### Parameters

The following parameters are available in the `polkit::user::hidepid_notify` class:

* [`log_level`](#-polkit--user--hidepid_notify--log_level)

##### <a name="-polkit--user--hidepid_notify--log_level"></a>`log_level`

Data type: `Any`

The log level to use when generating the notification message

Default value: `'warning'`

## Defined types

### <a name="polkit--authorization--basic_policy"></a>`polkit::authorization::basic_policy`

The intention of this define is to make it easy to add simple polkit rules
to a system. An example simple rule template is shown below:

```
// This file is managed by Puppet
polkit.addRule(function(action, subject) {
  if (<condition>) {
      return polkit.Result.<result>;
    }
  }
});
```

A user-specified <condition> can be supplied with the $condition parameter,
or the define can use the polkit::condition function to generate a condition
using $action_id, $user and/or $group, an (optionally) $local and $active.

* **See also**
  * polkit(8)

#### Examples

##### Allow users in the virtusers group to use the system libvirt

```puppet
polkit::authorization::basic_policy { 'Allow users to use libvirt':
  ensure    => present,
  group     => 'virtusers',
  result    => 'yes'
  action_id => 'org.libvirt.unix.manage',
  priority  => 20,
  local     => true,
  active    => true,
}

# Generates a policy file that looks like this
// This file is managed by Puppet
polkit.addRule(function(action, subject) {
  if ((action.id == 'org.libvirt.unix.manage') && subject.user == 'testuser' && subject.isInGroup('testgroup') && subject.local && subject.active) {
      return polkit.Result.YES;
    }
  }
});
```

#### Parameters

The following parameters are available in the `polkit::authorization::basic_policy` defined type:

* [`ensure`](#-polkit--authorization--basic_policy--ensure)
* [`result`](#-polkit--authorization--basic_policy--result)
* [`action_id`](#-polkit--authorization--basic_policy--action_id)
* [`user`](#-polkit--authorization--basic_policy--user)
* [`group`](#-polkit--authorization--basic_policy--group)
* [`local`](#-polkit--authorization--basic_policy--local)
* [`active`](#-polkit--authorization--basic_policy--active)
* [`condition`](#-polkit--authorization--basic_policy--condition)
* [`log_action`](#-polkit--authorization--basic_policy--log_action)
* [`log_subject`](#-polkit--authorization--basic_policy--log_subject)
* [`priority`](#-polkit--authorization--basic_policy--priority)
* [`rulesd`](#-polkit--authorization--basic_policy--rulesd)

##### <a name="-polkit--authorization--basic_policy--ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Create or destroy the rules file

Default value: `'present'`

##### <a name="-polkit--authorization--basic_policy--result"></a>`result`

Data type: `Polkit::Result`

The authorization result of the polkit transaction, for example `yes` or `auth_admin`

##### <a name="-polkit--authorization--basic_policy--action_id"></a>`action_id`

Data type: `Optional[String]`

The polkit action to operate on

* A list of available actions can be found by running `pkaction`

Default value: `undef`

##### <a name="-polkit--authorization--basic_policy--user"></a>`user`

Data type: `Variant[Undef,String,Array[String]]`

User to check

Default value: `undef`

##### <a name="-polkit--authorization--basic_policy--group"></a>`group`

Data type: `Variant[Undef,String,Array[String]]`

The group(s) that the user checking authorization belongs to

Default value: `undef`

##### <a name="-polkit--authorization--basic_policy--local"></a>`local`

Data type: `Boolean`

Check if the user is a local user. See man page for more explaination

Default value: `false`

##### <a name="-polkit--authorization--basic_policy--active"></a>`active`

Data type: `Boolean`

Check if the user is currently active. See man page for more explaination

Default value: `false`

##### <a name="-polkit--authorization--basic_policy--condition"></a>`condition`

Data type: `Optional[String]`

If specified, will be placed in the javascript condition to be met for polkit authorization

Default value: `undef`

##### <a name="-polkit--authorization--basic_policy--log_action"></a>`log_action`

Data type: `Boolean`

Log the action to the system log

Default value: `true`

##### <a name="-polkit--authorization--basic_policy--log_subject"></a>`log_subject`

Data type: `Boolean`

Log the subject to the system log

Default value: `true`

##### <a name="-polkit--authorization--basic_policy--priority"></a>`priority`

Data type: `Integer[0,99]`

Priority of the file to be created

Default value: `10`

##### <a name="-polkit--authorization--basic_policy--rulesd"></a>`rulesd`

Data type: `Stdlib::AbsolutePath`

Location of the poklit rules directory

Default value: `'/etc/polkit-1/rules.d'`

### <a name="polkit--authorization--rule"></a>`polkit::authorization::rule`

Add a rule file containing javascript Polkit configuration to the system

#### Parameters

The following parameters are available in the `polkit::authorization::rule` defined type:

* [`ensure`](#-polkit--authorization--rule--ensure)
* [`content`](#-polkit--authorization--rule--content)
* [`priority`](#-polkit--authorization--rule--priority)
* [`rulesd`](#-polkit--authorization--rule--rulesd)

##### <a name="-polkit--authorization--rule--ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Create or destroy the rules file

##### <a name="-polkit--authorization--rule--content"></a>`content`

Data type: `String`

An arbitrary string of javascript polkit configuration

##### <a name="-polkit--authorization--rule--priority"></a>`priority`

Data type: `Integer[0,99]`

Priority of the file to be created, lower priority means the rule would be read earlier

Default value: `10`

##### <a name="-polkit--authorization--rule--rulesd"></a>`rulesd`

Data type: `Stdlib::AbsolutePath`

Location of the poklit rules directory

Default value: `'/etc/polkit-1/rules.d'`

### <a name="polkit--local_authority"></a>`polkit::local_authority`

Add PolicyKit Local Authority policies to a system

Only the default ``authority`` directories are currently supported

* **See also**
  * pklocalauthority(8)

#### Examples

##### Local Test Policy

```puppet
polkit::local_authority { 'test_policy':
  identity        => 'unix-group:staff',
  action          => 'com.example.awesomeproduct.*',
  result_any      => 'no',
  result_inactive => 'no',
  result_active   => 'auth_admin'
}
```

#### Parameters

The following parameters are available in the `polkit::local_authority` defined type:

* [`name`](#-polkit--local_authority--name)
* [`identity`](#-polkit--local_authority--identity)
* [`action`](#-polkit--local_authority--action)
* [`ensure`](#-polkit--local_authority--ensure)
* [`target_directory`](#-polkit--local_authority--target_directory)
* [`authority`](#-polkit--local_authority--authority)
* [`order`](#-polkit--local_authority--order)
* [`section_name`](#-polkit--local_authority--section_name)
* [`result_active`](#-polkit--local_authority--result_active)
* [`result_inactive`](#-polkit--local_authority--result_inactive)
* [`result_any`](#-polkit--local_authority--result_any)
* [`return_value`](#-polkit--local_authority--return_value)

##### <a name="-polkit--local_authority--name"></a>`name`

A descriptive, valid **filename** (not path) in which to house your pkla entries

* Do not include the leading number or the trailing ``.pkla``

##### <a name="-polkit--local_authority--identity"></a>`identity`

Data type: `Variant[String,Array[String]]`

Identities as designated by ``pkla-check-authorization(8)``

Single entries may be entered as a String. Multiple entries should
be represented as an Array of entries and **NOT** a semicolon
separated string.

##### <a name="-polkit--local_authority--action"></a>`action`

Data type: `String`



##### <a name="-polkit--local_authority--ensure"></a>`ensure`

Data type: `Enum['file','absent','present']`

This passes directly down to the file type but only cares if you set it to
``absent``

Default value: `'present'`

##### <a name="-polkit--local_authority--target_directory"></a>`target_directory`

Data type: `Stdlib::Absolutepath`

The destination base directory for your ``pkla`` file

* Anything may be used, but logical values are:
    * ``/etc/polkit-1/localauthority``
    * ``/var/lib/polkit-1/localauthority``

Default value: `'/etc/polkit-1/localauthority'`

##### <a name="-polkit--local_authority--authority"></a>`authority`

Data type: `Polkit::Authority`

The local authority directory in which to store the pkla file

Supported values are:
  * local
  * mandatory
  * org
  * site
  * vendor

Default value: `'mandatory'`

##### <a name="-polkit--local_authority--order"></a>`order`

Data type: `Integer`

The ``order`` number given to your ``pkla`` file

* Higher numbers override lower ones in alphanumeric order

Default value: `50`

##### <a name="-polkit--local_authority--section_name"></a>`section_name`

Data type: `String`

The section name within the ``pkla`` file

Default value: `$name`

##### <a name="-polkit--local_authority--result_active"></a>`result_active`

Data type: `Polkit::Result`



Default value: `undef`

##### <a name="-polkit--local_authority--result_inactive"></a>`result_inactive`

Data type: `Polkit::Result`



Default value: `undef`

##### <a name="-polkit--local_authority--result_any"></a>`result_any`

Data type: `Polkit::Result`



Default value: `undef`

##### <a name="-polkit--local_authority--return_value"></a>`return_value`

Data type: `Polkit::Result`



Default value: `undef`

## Functions

### <a name="polkit--validate_identity"></a>`polkit::validate_identity`

Type: Ruby 4.x API

Validate that all entries are valid PolicyKit identities per
pkla-check-authorization(8).  Abort catalog compilation if any entry
fails this check.

#### `polkit::validate_identity(String $identity)`

The polkit::validate_identity function.

Returns: `Any` None

##### `identity`

Data type: `String`

Polkit identity; must begin with a 'unix-user:'
or 'unix_group:' header; the value portion can contain a wildcard.
For example, 'unix-user:username' or 'unix-group:mygroup*'

#### `polkit::validate_identity(Array[String] $identities)`

The polkit::validate_identity function.

Returns: `Any` None

##### `identities`

Data type: `Array[String]`

Array of Polkit identities; each must begin
with a 'unix-user:' or 'unix_group:' header; each value portion
can contain a wildcard.

## Data types

### <a name="Polkit--Authority"></a>`Polkit::Authority`

polkit authority types

Alias of `Enum['vendor', 'org', 'site', 'local', 'mandatory']`

### <a name="Polkit--PackageEnsure"></a>`Polkit::PackageEnsure`

Package ensure type

Alias of

```puppet
Variant[String, Enum[
    'latest',
    'installed',
    'absent',
    'purged'
  ]]
```

### <a name="Polkit--Result"></a>`Polkit::Result`

Polkit result types

Alias of

```puppet
Optional[Enum[
    'yes',
    'no',
    'auth_self',
    'auth_self_keep',
    'auth_admin',
    'auth_admin_keep',
  ]]
```

